==> ugene_1.3.3+repack.orig.tar.gz: ugene-1.3.3/src/core/src/gobjects/DNASequenceObject.cpp <==
/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#include "DNASequenceObject.h"

#include "GObjectTypes.h"

#include <core_api/DNAAlphabet.h>

namespace GB2 {

DNASequenceObject::DNASequenceObject(const QByteArray& seq, DNAAlphabet* al, const QString& objectName, const QVariantMap& hintsMap) 
: GObject(GObjectTypes::DNA_SEQUENCE, objectName, hintsMap), dnaSeq(seq, al)
{
    assert(al!=NULL);
    seqRange = LRegion(0, dnaSeq.seq.length());
}

DNASequenceObject::DNASequenceObject(const DNASequence& seq, const QString& objectName, const QVariantMap& hintsMap) 
: GObject(GObjectTypes::DNA_SEQUENCE, objectName, hintsMap), dnaSeq(seq)
{
    assert(dnaSeq.alphabet!=NULL);
    seqRange = LRegion(0, dnaSeq.seq.length());
}

GObject* DNASequenceObject::clone() const {
	DNASequenceObject* cln = new DNASequenceObject(dnaSeq.seq, dnaSeq.alphabet, getGObjectName(), getGHintsMap());
    return cln;
}

void DNASequenceObject::setBase(int pos, char base) {
	assert(pos >=0 && pos < dnaSeq.length());
	dnaSeq.seq[pos] = base;
	setModified(true);
}

bool DNASequenceObject::checkConstraints(const GObjectConstraints* c) const	{
	const DNASequenceObjectConstraints* dnac = qobject_cast<const DNASequenceObjectConstraints*>(c);
	bool resultDNAConstraints = true;
	bool resultAlphabetType = true;

	if (dnac->exactSequenceSize != dnaSeq.length()) {
		resultDNAConstraints = false;
	}
	if (dnac->exactSequenceSize <= 0)	{
		resultDNAConstraints = true;
	}
	if (dnac->alphabetType != getAlphabet()->getType())	{
		resultAlphabetType = false;
	}
	if (dnac->alphabetType == DNAAlphabet_RAW)	{
		resultAlphabetType = true;
	}

	return (resultDNAConstraints && resultAlphabetType);
}

DNASequenceObjectConstraints::DNASequenceObjectConstraints(QObject* p) : GObjectConstraints(GObjectTypes::DNA_SEQUENCE, p){}




}//namespace

==> ugene_1.5.2+repack.orig.tar.gz: ugene-1.5.2/src/core/src/gobjects/DNASequenceObject.cpp <==
/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#include "DNASequenceObject.h"

#include "GObjectTypes.h"

#include <core_api/DNAAlphabet.h>

namespace GB2 {

DNASequenceObject::DNASequenceObject(const QString& name, const DNASequence& seq, const QVariantMap& hintsMap) 
: GObject(GObjectTypes::DNA_SEQUENCE, name, hintsMap), dnaSeq(seq)
{
    assert(dnaSeq.alphabet!=NULL);
    seqRange = LRegion(0, dnaSeq.seq.length());
}

GObject* DNASequenceObject::clone() const {
	DNASequenceObject* cln = new DNASequenceObject(getGObjectName(), dnaSeq, getGHintsMap());
    cln->setIndexInfo(getIndexInfo());
    return cln;
}

void DNASequenceObject::setBase(int pos, char base) {
	assert(pos >=0 && pos < dnaSeq.length());
	dnaSeq.seq[pos] = base;
	setModified(true);
}

bool DNASequenceObject::checkConstraints(const GObjectConstraints* c) const	{
	const DNASequenceObjectConstraints* dnac = qobject_cast<const DNASequenceObjectConstraints*>(c);
	bool resultDNAConstraints = true;
	bool resultAlphabetType = true;

	if (dnac->exactSequenceSize != dnaSeq.length()) {
		resultDNAConstraints = false;
	}
	if (dnac->exactSequenceSize <= 0)	{
		resultDNAConstraints = true;
	}
	if (dnac->alphabetType != getAlphabet()->getType())	{
		resultAlphabetType = false;
	}
	if (dnac->alphabetType == DNAAlphabet_RAW)	{
		resultAlphabetType = true;
	}

	return (resultDNAConstraints && resultAlphabetType);
}

void DNASequenceObject::setSequence( DNASequence seq ){
    dnaSeq = seq;
    LRegion range(0, seq.length());
    seqRange = range;
    setModified(true);
    emit si_sequenceChanged();
}

DNASequenceObjectConstraints::DNASequenceObjectConstraints(QObject* p) : GObjectConstraints(GObjectTypes::DNA_SEQUENCE, p){}




}//namespace
